@@ -1,5 +1,5 @@
-from .gradient import *
 from .landscape import *
 from .spatiotemporal import *
+from .zonal import *
 
-__version__ = '0.3.1'
+__version__ = '2.0.1'
